# -*- coding: utf-8 -*-
"""CalibratedCatalog.

This module is part of the dataitem description.
All (concrete) dataitem classes have a one-to-one correspondence with
a specific FITS file type in the pipeline.

There are several base classes:
- Raw for raw data
- Img for processed images
- Cat for catalogs

This file is automatically generated. Do not modify!
"""

from micado.main.Cat import Cat, persistent
from micado.recipes.McdImgCalibratedCatalog import McdImgCalibratedCatalog
from micado.dataitems.Calibrated import Calibrated
from micado.dataitems.CalibratedCatalogQC import CalibratedCatalogQC


class CalibratedCatalog(Cat):
    """Calibrated Astrometric Imaging Catalog."""

    dummy_calibratedcatalog = persistent("dummy [][None]", int, 42)

    det_dit = persistent(
        "Detector integration time (average when NDIT > 1) [DET DIT][s]", float, 1.0
    )

    filtname = persistent("Filter name [INS FILT NAME][None]", str, "")

    mjdobs = persistent(
        "Modified Julian Day of the start of the exposure. The MJD is related to the "
        "Julian Day (JD) via the formula: MJD = JD-2400000.5 The comment includes a "
        "civil representation of the date and time. 8 decimals are required for a "
        "precision of one millisecond, 5 decimals for a precision of one second. [MJD-"
        "OBS][]",
        float,
        0.0,
    )

    tpl__start = persistent("Start time of template [TPL START][None]", float, 0.0)

    ra = persistent("Right Ascension [OBS RA][deg]", float, 0.0)

    dec = persistent("Declination [OBS DEC][deg]", float, 0.0)

    recipe = persistent("The recipe [][None]", McdImgCalibratedCatalog, None)

    calibrated = persistent("Fully detrended image [][None]", Calibrated, None)

    qc = persistent("Quality Control parameters [][None]", CalibratedCatalogQC, None)
