# -*- coding: utf-8 -*-
"""DepersistedBase.

This module is part of the dataitem description.
All (concrete) dataitem classes have a one-to-one correspondence with
a specific FITS file type in the pipeline.

There are several base classes:
- Raw for raw data
- Img for processed images
- Cat for catalogs

This file is automatically generated. Do not modify!
"""

from micado.main.Img import Img, persistent
from micado.recipes.McdDetDepersist import McdDetDepersist
from micado.main.Raw import Raw
from micado.dataitems.Persistence import Persistence
from micado.dataitems.DepersistedExtension import DepersistedExtension
from micado.dataitems.DepersistedQC import DepersistedQC


class DepersistedBase(Img):
    """Persistence corrected image."""

    dummy_depersistedbase = persistent("dummy [][None]", int, 42)

    det_dit = persistent(
        "Detector integration time (average when NDIT > 1) [DET DIT][s]", float, 1.0
    )

    readmode = persistent(
        "Readout mode of the detector [DET READOUT][None]", str, "CDS"
    )

    mjdobs = persistent(
        "Modified Julian Day of the start of the exposure. The MJD is related to the "
        "Julian Day (JD) via the formula: MJD = JD-2400000.5 The comment includes a "
        "civil representation of the date and time. 8 decimals are required for a "
        "precision of one millisecond, 5 decimals for a precision of one second. [MJD-"
        "OBS][]",
        float,
        0.0,
    )

    tpl__start = persistent("Start time of template [TPL START][None]", float, 0.0)

    tpl__expno = persistent(
        "Number of this exposure in a Template [TPL EXPNO][None]", int, 0
    )

    obs__tplno = persistent(
        "Number of the template of this exposure in an ObservingBlock [OBS TPLNO][None]",
        int,
        0,
    )

    recipe = persistent("The recipe [][None]", McdDetDepersist, None)

    raw = persistent("Raw data [][None]", Raw, None)

    persistence = persistent("Persistence Image [][None]", Persistence, None)

    extensions = persistent("DepersistedExtension [][None]", DepersistedExtension, [])

    qc = persistent("Quality Control parameters [][None]", DepersistedQC, None)
