# -*- coding: utf-8 -*-
"""MasterDark.

This module is part of the dataitem description.
All (concrete) dataitem classes have a one-to-one correspondence with
a specific FITS file type in the pipeline.

There are several base classes:
- Raw for raw data
- Img for processed images
- Cat for catalogs

This file is automatically generated. Do not modify!
"""

from micado.main.Img import Img, persistent
from micado.recipes.McdDetDark import McdDetDark
from micado.dataitems.DepersistedDark import DepersistedDark
from micado.requirements.DPSmasterdarkX import DPSmasterdarkX
from micado.dataitems.MasterDarkExtension import MasterDarkExtension
from micado.dataitems.MasterDarkQC import MasterDarkQC


class MasterDark(Img):
    """MasterDark calibration image."""

    dummy_masterdark = persistent("dummy [][None]", int, 42)

    det_dit = persistent(
        "Detector integration time (average when NDIT > 1) [DET DIT][s]", float, 1.0
    )

    readmode = persistent(
        "Readout mode of the detector [DET READOUT][None]", str, "CDS"
    )

    recipe = persistent("The recipe [][None]", McdDetDark, None)

    darks = persistent("A list of raw Darks [][None]", DepersistedDark, [])

    requirement = persistent("None [][None]", DPSmasterdarkX, None)

    extensions = persistent("MasterDarkExtensions [][None]", MasterDarkExtension, [])

    qc = persistent("MasterDarkQC [][None]", MasterDarkQC, None)
