# -*- coding: utf-8 -*-
"""MasterFlat.

This module is part of the dataitem description.
All (concrete) dataitem classes have a one-to-one correspondence with
a specific FITS file type in the pipeline.

There are several base classes:
- Raw for raw data
- Img for processed images
- Cat for catalogs

This file is automatically generated. Do not modify!
"""

from micado.main.Img import Img, persistent
from micado.recipes.McdImgFlat import McdImgFlat
from micado.dataitems.DepersistedFlat import DepersistedFlat
from micado.dataitems.MasterDark import MasterDark
from micado.requirements.DPSflatfield import DPSflatfield
from micado.dataitems.MasterFlatExtension import MasterFlatExtension
from micado.dataitems.MasterFlatQC import MasterFlatQC


class MasterFlat(Img):
    """MasterFlat.

    Flatfield image obtained by combining a series of internal flatfield lamp
    observations.
    """

    dummy_masterflat = persistent("dummy [][None]", int, 42)

    det_dit = persistent(
        "Detector integration time (average when NDIT > 1) [DET DIT][s]", float, 1.0
    )

    readmode = persistent(
        "Readout mode of the detector [DET READOUT][None]", str, "CDS"
    )

    filtname = persistent("Filter name [INS FILT NAME][None]", str, "")

    recipe = persistent("The recipe [][None]", McdImgFlat, None)

    flats = persistent("A list of raw Flats [][None]", DepersistedFlat, [])

    masterdark = persistent("MasterDark. [][None]", MasterDark, None)

    requirement = persistent("None [][None]", DPSflatfield, None)

    extensions = persistent("MasterFlatExtensions [][None]", MasterFlatExtension, [])

    qc = persistent("Quality Control parameters [][None]", MasterFlatQC, None)
