# -*- coding: utf-8 -*-
"""DetectorArray.

This module is part of the hardware description.
All hardware clasess have a one-to-one correspondence with a class in
the irdb: https://github.com/AstarVienna/irdb

The base Hardware class has two subclasses:
- HardwareThing, which is Atmosphere/Telescope/Detector/... etc.
- Effect, which is Shotnoise/Nonlinearity/... etc.

These classes also provide default instances. The values of those
instances are derived from the IRDB.

In the future it might be better to generate these classes directly
from the IRDB.

This file is automatically generated. Do not modify!
"""

from micado.main.HardwareThing import HardwareThing, persistent
from micado.hardware.Detector import Detector, default_detector
from micado.hardware.DarkCurrent import DarkCurrent, default_darkcurrent
from micado.hardware.ShotNoise import ShotNoise, default_shotnoise
from micado.hardware.QuantumEfficiencyCurve import (
    QuantumEfficiencyCurve,
    default_quantumefficiencycurve,
)
from micado.hardware.LinearityCurve import LinearityCurve, default_linearitycurve
from micado.hardware.SummedExposure import SummedExposure, default_summedexposure
from micado.hardware.PoorMansHxRGReadoutNoise import (
    PoorMansHxRGReadoutNoise,
    default_poormanshxrgreadoutnoise,
)
from micado.hardware.ReferencePixelBorder import (
    ReferencePixelBorder,
    default_referencepixelborder,
)

default_detector_array_list_list = [
    Detector(
        id=1,
        x_cen=-63.94,
        y_cen=63.94,
        x_size=4096,
        y_size=4096,
        pixel_size=0.015,
        angle=0.0,
        gain=1.0,
    ),
    Detector(
        id=2,
        x_cen=0.0,
        y_cen=63.94,
        x_size=4096,
        y_size=4096,
        pixel_size=0.015,
        angle=270.0,
        gain=1.0,
    ),
    Detector(
        id=3,
        x_cen=63.94,
        y_cen=63.94,
        x_size=4096,
        y_size=4096,
        pixel_size=0.015,
        angle=180.0,
        gain=1.0,
    ),
    Detector(
        id=6,
        x_cen=-63.94,
        y_cen=0.0,
        x_size=4096,
        y_size=4096,
        pixel_size=0.015,
        angle=0.0,
        gain=1.0,
    ),
    Detector(
        id=5,
        x_cen=0.0,
        y_cen=0.0,
        x_size=4096,
        y_size=4096,
        pixel_size=0.015,
        angle=180.0,
        gain=1.0,
    ),
    Detector(
        id=4,
        x_cen=67.94,
        y_cen=0.0,
        x_size=4096,
        y_size=4096,
        pixel_size=0.015,
        angle=180.0,
        gain=1.0,
    ),
    Detector(
        id=7,
        x_cen=-63.94,
        y_cen=-63.94,
        x_size=4096,
        y_size=4096,
        pixel_size=0.015,
        angle=0.0,
        gain=1.0,
    ),
    Detector(
        id=8,
        x_cen=0.0,
        y_cen=-63.94,
        x_size=4096,
        y_size=4096,
        pixel_size=0.015,
        angle=90.0,
        gain=1.0,
    ),
    Detector(
        id=9,
        x_cen=63.94,
        y_cen=-63.94,
        x_size=4096,
        y_size=4096,
        pixel_size=0.015,
        angle=180.0,
        gain=1.0,
    ),
]


class DetectorArray(HardwareThing):
    """A detector array."""

    dummy_detectorarray = persistent("dummy [][None]", int, 42)

    name = persistent("Name of the detector array [DET NAME][None]", str, "")

    image_plane_id = persistent(
        "Number of this detector in the image plane [DET IMAGE_PL][None]", int, 0
    )

    temperature = persistent(
        "Temperature of detector array [DET TEMPERAT][C]", float, -230.0
    )

    readout = persistent("Readout mode of the detector [DET READOUT][None]", str, "CDS")

    detector_array_list = persistent(
        "Detectors [][None]", Detector, default_detector_array_list_list
    )

    dark_current = persistent("DarkCurrent [][None]", DarkCurrent, default_darkcurrent)

    shot_noise = persistent("ShotNoise [][None]", ShotNoise, default_shotnoise)

    qe_curve = persistent(
        "QuantumEfficiencyCurve [][None]",
        QuantumEfficiencyCurve,
        default_quantumefficiencycurve,
    )

    linearity = persistent(
        "LinearityCurve [][None]", LinearityCurve, default_linearitycurve
    )

    exposure_action = persistent(
        "SummedExposure [][None]", SummedExposure, default_summedexposure
    )

    readout_noise = persistent(
        "ReadoutNoise [][None]",
        PoorMansHxRGReadoutNoise,
        default_poormanshxrgreadoutnoise,
    )

    reference_pixel_border = persistent(
        "ReferencePixelBorder [][None]",
        ReferencePixelBorder,
        default_referencepixelborder,
    )


default_detectorarray = DetectorArray(
    name="",
    image_plane_id=0,
    temperature=-230.0,
    readout="CDS",
    detector_array_list=default_detector_array_list_list,
    dark_current=default_darkcurrent,
    shot_noise=default_shotnoise,
    qe_curve=default_quantumefficiencycurve,
    linearity=default_linearitycurve,
    exposure_action=default_summedexposure,
    readout_noise=default_poormanshxrgreadoutnoise,
    reference_pixel_border=default_referencepixelborder,
)
