# -*- coding: utf-8 -*-
"""Hardware that represents an effect."""

from micado.main.Hardware import Hardware
from micado.util.irdb import INSTRUMENT, get_effect


class EffectExtra(Hardware):
    """Hardware that represents an effect.

    This class is necessary to overload scopesim_dictionary.
    """

    @property
    def scopesim_dictionary(self):
        """Create ScopeSIM dictionary from value."""
        dd = super(EffectExtra, self).scopesim_dictionary
        kwargs1 = dd.pop("kwargs")
        # Convert from OrderedDict to dict.
        # Do not pass empty values, e.g. filename, globalname.
        kwargs2 = {
            # TODO: Fix realfilename hack.
            k.replace("realfilename", "filename"): v
            for k, v in kwargs1.items()
            if v not in ["", None]
        }

        # TODO: Place in FilterWheelExtra.py?
        if "filter_name" in kwargs2 or "current_filter" in kwargs2:
            if "filename_format" not in kwargs2:
                kwargs2["filename_format"] = "filters/TC_filter_{}.dat"
            if "filter_names" not in kwargs2:
                # TODO: Split up per wheel? Doesn't seem to add anything.
                filters1 = get_effect(INSTRUMENT, "filter_wheel_1")["kwargs"][
                    "filter_names"
                ]
                filters2 = get_effect(INSTRUMENT, "filter_wheel_2")["kwargs"][
                    "filter_names"
                ]
                kwargs2["filter_names"] = filters1 + filters2

        dd["kwargs"] = kwargs2
        return dd
