# -*- coding: utf-8 -*-
"""Requirement."""

import re

from micado.main.MObject import MObject


class RequirementExtra(MObject):
    """Requirement."""

    @classmethod
    def name_eso(cls):
        """Generate ESO compliant name from Python class.

        E.g. DPS3000SCI -> DPS-3000-SCI

        DPSnonlinear -> DPS-nonlinear

        DPSmasterdarkX -> DPS-masterdark
        """
        # Hack to get -X inverse requirements the same name.
        # TODO: Fix this hack.
        name = cls.__name__.strip("X")
        match1 = re.match(
            r"(\D+)(\d+)(\D+)",
            name,
        )
        if match1:
            return "-".join(match1.groups())

        match2 = re.match(
            r"(DPS)(\w+)",
            name,
        )
        if match2:
            return "-".join(match2.groups())

        raise ValueError(f"No name_eso() for {cls}")

    @classmethod
    def get_parent_ids(cls):
        """Get parent requirement id from docstring."""
        lines = [
            line.strip().strip(".")
            for line in cls.__doc__.splitlines()
            # TODO: Harmonize on a single representation of parent requirements.
            if "[R-" in line or " R_" in line or "[I-" in line
        ]
        sline = " ".join(lines)
        sline = sline.strip().split("Parents:")[1].strip()
        # E.g. [R-MCD-100] -> R-MCD-100
        # TODO: Fix this inconsistency
        if sline.count("[") == 1:
            sline = sline.strip("[]")
        return sline
